==> PgXexplorer-0.24.tar.bz2: PgXexplorer-0.24/query.h <==
/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 FILE: query.h */
#ifndef __MORGOTHDBMA_QUERY_H__
#define __MORGOTHDBMA_QUERY_H__
#define MAX_ERROR_STRING 4096
#define MAX_QUERY_LENGTH 4096
#include "ilibpq.h"
#include <string.h>
#include "consoleout.h"
#include "mmsystem.h"
PGconn* connect_db(char*);
PGconn* gtk_connect_db(char*,char*);
void clear_result(PGresult**);
void disconnect_db(PGconn**);
PGresult* execute_silent_query(PGconn*,char*);
PGresult* execute_query(PGconn*,char*);
void execute_printf_query(PGconn*,PGresult**,char*, char*,...);
void execute_printf(PGconn*,char****, int*, int*, char*, int, char*,...);
void mexecute_printf(PGconn*,char****, int*, int*, char*, int, char*,...);
void mem_execute_printf(struct mem_list**, PGconn*,char****, int*, int*, char*, int, char*,...);
void dmexecute_printf(PGconn*,char****, int*, int*, char*, int, char*,int,char*,...);
void dmem_execute_printf(struct dmem_list**, PGconn*,char****, int*, int*, char*, int, char*,int,char*,...);
char*** p3c_execute_printf(PGconn*,int*, int*,char*,int, char*,...);
char*** mp3c_execute_printf(PGconn*,int*, int*,char*,int, char*,...);
char*** mem_p3c_execute_printf(struct mem_list**, PGconn*,int*, int*,char*,int, char*,...);
char*** dmp3c_execute_printf(PGconn*,int*, int*,char*,int, char*,int,char*,...);
char*** dmem_p3c_execute_printf(struct dmem_list**, PGconn*,int*, int*,char*,int, char*,int,char*,...);
char*** pgres2pc3(const PGresult*,int*,int*, int);
char*** mpgres2pc3(const PGresult*,int*,int*, int);
char*** mem_pgres2pc3(struct mem_list**,const PGresult*,int*,int*, int);
char*** dmpgres2pc3(const PGresult*,int*,int*, int,char*,int);
char*** dmem_pgres2pc3(struct dmem_list**,const PGresult*,int*,int*, int,char*,int);
void free_p3c(char****,int,int);
void mfree_p3c(char****,int,int);
void dmfree_p3c(char****,int,int,char*,int);
void mem_free_p3c(struct mem_list**,char****,int,int);
void dmem_free_p3c(struct dmem_list**,char****,int,int,char*,int);
int get_db_tables(PGconn*,char***, int*,int);
int mget_db_tables(PGconn*,char***, int*,int);
int mem_get_db_tables(struct mem_list**, PGconn*,char***, int*,int);
int dmget_db_tables(PGconn*,char***, int*,int,char*,int);
int dmem_get_db_tables(struct dmem_list**, PGconn*,char***, int*,int,char*,int);
#endif

==> PgXexplorer-0.27.tar.bz2: PgXexplorer-0.27/query.h <==
/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 FILE: query.h */
#ifndef __MORGOTHDBMA_QUERY_H__
#define __MORGOTHDBMA_QUERY_H__
#define MAX_ERROR_STRING 4096
#define MAX_QUERY_LENGTH 4096
#include "ilibpq.h"
#include <string.h>
#include "consoleout.h"
#include "mmsystem.h"


PGconn* connect_db(char*, char*);
PGconn* gtk_connect_db(char*,char*,char*);
void clear_result(PGresult**);
void disconnect_db(PGconn**);
PGresult* execute_silent_query(PGconn*,char*);
PGresult* execute_query(PGconn*,char*);
void execute_printf_query(PGconn*,PGresult**,char*, char*,...);
void execute_printf(PGconn*,char****, int*, int*, char*, int, char*,...);
void mexecute_printf(PGconn*,char****, int*, int*, char*, int, char*,...);
void mem_execute_printf(struct mem_list**, PGconn*,char****, int*, int*, char*, int, char*,...);
void dmexecute_printf(PGconn*,char****, int*, int*, char*, int, char*,int,char*,...);
void dmem_execute_printf(struct dmem_list**, PGconn*,char****, int*, int*, char*, int, char*,int,char*,...);
char*** p3c_execute_printf(PGconn*,int*, int*,char*,int, char*,...);
char*** mp3c_execute_printf(PGconn*,int*, int*,char*,int, char*,...);
char*** mem_p3c_execute_printf(struct mem_list**, PGconn*,int*, int*,char*,int, char*,...);
char*** dmp3c_execute_printf(PGconn*,int*, int*,char*,int, char*,int,char*,...);
char*** dmem_p3c_execute_printf(struct dmem_list**, PGconn*,int*, int*,char*,int, char*,int,char*,...);
char*** pgres2pc3(const PGresult*,int*,int*, int);
char*** mpgres2pc3(const PGresult*,int*,int*, int);
char*** mem_pgres2pc3(struct mem_list**,const PGresult*,int*,int*, int);
char*** dmpgres2pc3(const PGresult*,int*,int*, int,char*,int);
char*** dmem_pgres2pc3(struct dmem_list**,const PGresult*,int*,int*, int,char*,int);
void free_p3c(char****,int,int);
void mfree_p3c(char****,int,int);
void dmfree_p3c(char****,int,int,char*,int);
void mem_free_p3c(struct mem_list**,char****,int,int);
void dmem_free_p3c(struct dmem_list**,char****,int,int,char*,int);
int get_db_tables(PGconn*,char***, int*,int);
int mget_db_tables(PGconn*,char***, int*,int);
int mem_get_db_tables(struct mem_list**, PGconn*,char***, int*,int);
int dmget_db_tables(PGconn*,char***, int*,int,char*,int);
int dmem_get_db_tables(struct dmem_list**, PGconn*,char***, int*,int,char*,int);
#endif
